#!/bin/perl

###############################################################################
#
# This file can be distributed and modified freely, as long as this original
# header is not modified.
#
# Author:         Nicolas Hatier <nicolas dot hatier at niversoft dot com>
# Organization:   Niversoft ides logicielles / software ideas.
# Date:           July 2004
#
# This code is provided AS IS, without any certification that it will even run
#
###############################################################################

# This filter is implemented as a Content-Filtering script for Communicate Pro
# Presence of the "already-processed" header is NOT automatically verified by
# this script. To avoid infinite message loops in the server, YOU MUST verify it
# in a Rule before passing the message to this script. The Rule to add is:
#     Data:    Header Field    is not    X-Header-Trimmer:*
#     Action:  ExternalFilter            HeaderTrimmer
#
# This script requires headertrimmer 2.3, which can be downloaded from
# http://x42.com/software/mail
#
# This script may be compatible with a further version of headertrimmer, but the
#  modifications to apply may be different
#
# The headertrimmer script must be named "2822htrim.pl" and must be located in
# the same directory as this script. 2822htrim.pl has to be modified the
# following way. All modifications occurs near the end of the script :
#
#  - Replace the two instances of "STDIN" by "FILE_IN"
#	    line 442:  while (<STDIN>)           ->   while (<FILE_IN>)
#      line 460:  print while (<STDIN>);    ->   print while (<FILE_IN>);
#
#  - Add "FILE_OUT" to the two "print" commands. DO NOT add commas:
#      line 458:  print $newheaders;        ->   print FILE_OUT $newheaders;
#      line 460:  print while (<FILE_IN>);  ->   print FILE_OUT while (<FILE_IN>);
#
#

sub Log
{
   print "* $_[0]\n";
}

$| = 1;

my $rundir = $0;
$rundir =~ s|\\|/|g;
$rundir = index($rundir, "/")>=0 ? substr($rundir, 0, rindex($rundir, "/")) : ".";

Log "HeaderTrimmer Content-Filter is running";
Log "";

mkdir "Submitted" if (!-d "Submitted");

while (<>)
{
   my @line = split(/ /, $_);
  chomp($line[0]);

   # Verifying the command send by the server.
   print "$line[0] OK\n"      and next if ($line[1] =~ /^quit$/i);
   print "$line[0] INTF 3\n"  and next if ($line[1] =~ /^intf$/i);
   print "$line[0] OK\n"      and next if ($line[1] =~ /^key$/i);
	print "$line[0] FAILURE\n" and next if ($line[1] !~ /^file$/i); # other unsupported commands

   $line[2] =~ s|\\|/|g; # Getting the filepath
   chomp($line[2]);

   if (!open(FILE_IN, "<$line[2]"))
   {
      Log "File Not Found $line[2]";
      print "$line[0] OK\n";
   }
   else
   {
      my ($sender, @recipients);

      # This while loop is taken from notifyRecipients.pl that comes in
      # the CGPMcAfee package
      # This extracts the envelope information
      while(1)
      {
         $line = <FILE_IN>;
         chomp($line);
         last if($line eq '');
         if($line =~ /^(\w).+<(.+)>/)
         {
            if($1 eq 'P')
            {
               $sender = $2;
            }
            else
            {
               push @recipients, $2;
            }
         }
      }

      my $alertFileName.="Submitted/A".time().int(rand(10000));

      open FILE_OUT, ">$alertFileName.tmp";

      print FILE_OUT "Return-Path: $sender\n";
      print FILE_OUT "Envelope-To: ". join(", ", @recipients)."\n";

      # we now run the modified headertrimmer script
      do "$rundir/2822htrim.pl";

      close FILE_OUT;
      close FILE_IN;

      rename("$alertFileName.tmp","$alertFileName.sub");

      # We tell the server to discard the original message
      print "$line[0] DISCARD\n";

   }

   # Just to ensure that STDOUT is correctly flushed and that the
   # server understands our replies.
   open STDOUT, ">&STDOUT";
}


